@@ -51,7 +51,7 @@ class WidgetsScheme(Scheme):
         Scheme.__init__(self, parent, title, description)
 
         self.signal_manager = WidgetsSignalManager(self)
-        self.widget_manager = WidgetManager(self)
+        self.widget_manager = WidgetManager()
         self.widget_manager.set_scheme(self)
 
     def widget_for_node(self, node):
@@ -83,6 +83,12 @@ class WidgetsScheme(Scheme):
         log.debug("Scheme node properties sync (changed: %s)", changed)
         return changed
 
+    def show_report_view(self):
+        from OWReport import get_instance
+        inst = get_instance()
+        inst.show()
+        inst.raise_()
+
 
 class WidgetManager(QObject):
     """
@@ -105,7 +111,7 @@ class WidgetManager(QObject):
     #:   * ProcessingUpdate - widget has entered processing state
     InputUpdate, BlockingUpdate, ProcessingUpdate = 1, 2, 4
 
-    def __init__(self, parent):
+    def __init__(self, parent=None):
         QObject.__init__(self, parent)
         self.__scheme = None
         self.__signal_manager = None
@@ -268,6 +274,10 @@ class WidgetManager(QObject):
                      SIGNAL("blockingStateChanged(bool)"),
                      self.__on_blocking_state_changed)
 
+        if widget.isBlocking():
+            # A widget can already enter blocking state in __init__
+            self.__widget_processing_state[widget] |= self.BlockingUpdate
+
         # Install a help shortcut on the widget
         help_shortcut = QShortcut(QKeySequence("F1"), widget)
         help_shortcut.activated.connect(self.__on_help_request)
@@ -294,7 +304,7 @@ class WidgetManager(QObject):
         return self.__widget_processing_state[widget]
 
     def eventFilter(self, receiver, event):
-        if receiver is self.__scheme and event.type() == QEvent.Close:
+        if event.type() == QEvent.Close and receiver is self.__scheme:
             self.signal_manager().stop()
 
             # Notify the widget instances.
@@ -708,8 +718,18 @@ class WidgetsSignalManager(SignalManager):
         return SignalManager.event(self, event)
 
     def eventFilter(self, receiver, event):
-        if receiver is self.scheme() and event.type() == QEvent.DeferredDelete:
-            if self.runtime_state() == SignalManager.Processing:
+        if event.type() == QEvent.DeferredDelete and receiver is self.scheme():
+            try:
+                state = self.runtime_state()
+            except AttributeError:
+                # If the scheme (which is a parent of this object) is
+                # already being deleted the SignalManager can also be in
+                # the process of destruction (noticeable by its __dict__
+                # being empty). There is nothing really to do in this
+                # case.
+                state = None
+
+            if state == SignalManager.Processing:
                 log.info("Deferring a 'DeferredDelete' event for the Scheme "
                          "instance until SignalManager exits the current "
                          "update loop.")
