@@ -1,24 +1,3 @@
-/*
-    This file is part of Orange.
-    
-    Copyright 1996-2010 Faculty of Computer and Information Science, University of Ljubljana
-    Contact: janez.demsar@fri.uni-lj.si
-
-    Orange is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    Orange is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with Orange.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
-
 #ifdef _MSC_VER
   #pragma warning (disable : 4786 4114 4018 4267 4244)
 #endif
@@ -1328,25 +1307,53 @@ C_CALL(LinearLearner, Learner, "([examples] -/-> Classifier)")
 C_NAMED(LinearClassifier - Orange.classification.svm.LinearClassifier, ClassifierFD, " ")
 
 
+PyObject * LinearClassifier_new(PyTypeObject* type, PyObject* args, PyObject* kwargs) BASED_ON(ClassifierFD, "(Domain, str) -> LinearClassifier")
+{
+	PyTRY
+		PDomain domain;
+		char * model_string;
 
-PyObject *LinearClassifier__reduce__(PyObject *self){
+		if (!PyArg_ParseTuple(args, "O&s:__new__", cc_Domain, &domain, &model_string)) {
+			return NULL;
+		}
+		string buf(model_string);
+		struct model * model = linear_load_model_alt(buf);
+
+		PLinearClassifier classifier = mlnew TLinearClassifier(domain, model);
+
+		return WrapOrange(classifier);
+	PyCATCH
+}
+
+
+PyObject *LinearClassifier__reduce__(PyObject *self)
+{
   PyTRY
 	CAST_TO(TLinearClassifier, classifier);
 	string buff;
 	if (linear_save_model_alt(buff, classifier->getModel()) != 0)
 		raiseError("Could not save the model");
-	return Py_BuildValue("O(OOOs)N", getExportedFunction("__pickleLoaderLinearClassifier"),
-									self->ob_type,
-									WrapOrange(classifier->classVar),
-									WrapOrange(classifier->examples),
-									buff.c_str(),
-									packOrangeDictionary(self));
+
+	return Py_BuildValue(
+			"O(Os)N",
+			self->ob_type,
+			WrapOrange(classifier->domain),
+			buff.c_str(),
+			packOrangeDictionary(self));
   PyCATCH
 }
 
-PyObject *__pickleLoaderLinearClassifier(PyObject *, PyObject *args) PYARGS(METH_VARARGS, "(type, packed_data)")
+/*
+ * Deprecated. Left here so old pickled objects can be restored.
+ * The old pickled arguments were:
+ *
+ *     (type(self), classVar, examples, model_string),
+ */
+
+PyObject *__pickleLoaderLinearClassifier(PyObject *, PyObject *args) PYARGS(METH_VARARGS, "(type, packed_data) Deprecated!!")
 {
   PyTRY
+	//raiseWarning(PyExc_DeprecationWarning, "Deprecated pickle reconstructor")
 	PyTypeObject* type;
     PVariable var;
 	PExampleTable examples;
@@ -1357,10 +1364,24 @@ PyObject *__pickleLoaderLinearClassifier(PyObject *, PyObject *args) PYARGS(METH
 	model *model = linear_load_model_alt(buff);
 	if (!model)
 		raiseError("Could not load the model");
-	return WrapNewOrange(mlnew TLinearClassifier(var, examples, model), (PyTypeObject*)&PyOrLinearClassifier_Type);
+	return WrapNewOrange(mlnew TLinearClassifier(examples->domain, model), (PyTypeObject*)&PyOrLinearClassifier_Type);
   PyCATCH
 }
 
+
+PyObject * LinearClassifer_get_model_str(PyObject * self, PyObject *) PYARGS(METH_NOARGS, "() -> str")
+{
+	PyTRY
+		CAST_TO(TLinearClassifier, classifier);
+		string buff;
+		if (linear_save_model_alt(buff, classifier->getModel()) != 0) {
+			raiseError("Could not convert the model to a string");
+		}
+		return PyString_FromString(buff.c_str());
+	PyCATCH
+}
+
+
 /************* LIBSVM ************/
 
 #include "libsvm_interface.hpp"
@@ -1452,20 +1473,13 @@ PyObject *SVMClassifier__reduce__(PyObject* self)
     if (svm_save_model_alt(buf, svm->getModel())){
     	raiseError("Error saving SVM model");
     }
-    if(svm->kernelFunc)
-        return Py_BuildValue("O(OOOsO)N", self->ob_type,
-                                    WrapOrange(svm->classVar),
-                                    WrapOrange(svm->examples),
-                                    WrapOrange(svm->supportVectors),
+
+    return Py_BuildValue("O(OsOOO)N", self->ob_type,
+                                    WrapOrange(svm->domain),
                                     buf.c_str(),
+                                    WrapOrange(svm->supportVectors),
                                     WrapOrange(svm->kernelFunc),
-                                    packOrangeDictionary(self));
-    else
-        return Py_BuildValue("O(OOOs)N", self->ob_type,
-                                    WrapOrange(svm->classVar),
                                     WrapOrange(svm->examples),
-                                    WrapOrange(svm->supportVectors),
-                                    buf.c_str(),
                                     packOrangeDictionary(self));
   PyCATCH
 }
@@ -1479,22 +1493,14 @@ PyObject *SVMClassifierSparse__reduce__(PyObject* self)
     if (svm_save_model_alt(buf, svm->getModel())){
         raiseError("Error saving SVM model.");
     }
-    if(svm->kernelFunc)
-        return Py_BuildValue("O(OOOsbO)N", self->ob_type,
-                                    WrapOrange(svm->classVar),
-                                    WrapOrange(svm->examples),
-                                    WrapOrange(svm->supportVectors),
-                                    buf.c_str(),
-									(char)(svm->useNonMeta? 1: 0),
-                                    WrapOrange(svm->kernelFunc),
-                                    packOrangeDictionary(self));
-    else
-        return Py_BuildValue("O(OOOsb)N", self->ob_type,
-                                    WrapOrange(svm->classVar),
-                                    WrapOrange(svm->examples),
-                                    WrapOrange(svm->supportVectors),
+
+    return Py_BuildValue("O(OsbOOO)N", self->ob_type,
+                                    WrapOrange(svm->domain),
                                     buf.c_str(),
                                     (char)(svm->useNonMeta? 1: 0),
+                                    WrapOrange(svm->supportVectors),
+                                    WrapOrange(svm->kernelFunc),
+                                    WrapOrange(svm->examples),
                                     packOrangeDictionary(self));
   PyCATCH
 }
@@ -1522,102 +1528,104 @@ PyCATCH
 }
 
 
-PyObject * SVMClassifier_new(PyTypeObject* type, PyObject* args, PyObject* kwargs) BASED_ON(ClassifierFD, "(Variable, Examples, Examples, string, [kernelFunc]) -> SVMClassifier")
-{PyTRY
-	PVariable classVar;
-	PExampleTable examples;
+PyObject * SVMClassifier_new(PyTypeObject* type, PyObject* args, PyObject* kwargs) BASED_ON(ClassifierFD, "(Domain, model_string, supportVectors, [kernelFunc, examples]) -> SVMClassifier")
+{
+PyTRY
+	PDomain domain;
+	char*  model_string = NULL;
 	PExampleTable supportVectors;
-	char*  model_string;
 	PKernelFunc kernel;
+	PExampleTable examples;
+
 	if (PyArg_ParseTuple(args, ""))
 		return WrapNewOrange(mlnew TSVMClassifier(), type);
+
 	PyErr_Clear();
-	
-	if (!PyArg_ParseTuple(args, "O&O&O&s|O&:__new__", cc_Variable, &classVar, cc_ExampleTable, &examples, cc_ExampleTable, &supportVectors, &model_string, cc_KernelFunc, &kernel))
-		return NULL;
+
+	if (!PyArg_ParseTuple(args, "O&sO&|O&O&",
+			cc_Domain, &domain,
+			&model_string,
+			cc_ExampleTable, &supportVectors,
+			ccn_KernelFunc, &kernel,
+			ccn_ExampleTable, &examples)) {
+		 // Old pickle arguments format.
+		PVariable classVar;
+		if (!PyArg_ParseTuple(args, "O&O&O&s|O&:__new__",
+				cc_Variable, &classVar,
+				ccn_ExampleTable, &examples,
+				cc_ExampleTable, &supportVectors,
+				&model_string,
+				cc_KernelFunc, &kernel)) {
+			return NULL;
+		}
+		PyErr_Clear();
+		domain = supportVectors->domain;
+	}
 
 	string buffer(model_string);
 	svm_model* model = svm_load_model_alt(buffer);
 	if (!model)
 		raiseError("Error building LibSVM Model");
-//	model->param.learner = NULL;
-	PSVMClassifier svm = mlnew TSVMClassifier(classVar, examples, model, NULL, kernel);
-//	svm->kernelFunc = kernel;
-	svm->supportVectors = supportVectors;
+
+	PSVMClassifier svm = mlnew TSVMClassifier(domain, model, supportVectors, kernel, examples);
+
 	return WrapOrange(svm);
 PyCATCH
 }
 
-PyObject * SVMClassifierSparse_new(PyTypeObject* type, PyObject* args, PyObject* kwargs) BASED_ON(SVMClassifier, "(Variable, Examples, Examples, string, [useNonMeta, kernelFunc]) -> SVMClassifierSparse")
-{PyTRY
-	PVariable classVar;
-	PExampleTable examples;
+
+
+PyObject * SVMClassifierSparse_new(PyTypeObject* type, PyObject* args, PyObject* kwargs) BASED_ON(SVMClassifier, "(Domain, model_string, useNonMeta, supportVectors, [kernelFunc, examples]) -> SVMClassifierSparse")
+{
+PyTRY
+	PDomain domain;
+	char*  model_string = NULL;
+	char useNonMeta = 0;
+
 	PExampleTable supportVectors;
-	char*  model_string;
-	char useNonMeta;
 	PKernelFunc kernel;
+	PExampleTable examples;
+
 	if (PyArg_ParseTuple(args, ""))
 		return WrapNewOrange(mlnew TSVMClassifierSparse(), type);
+
 	PyErr_Clear();
-	
-	if (!PyArg_ParseTuple(args, "O&O&O&s|bO&:__new__", cc_Variable, &classVar, cc_ExampleTable, &examples, cc_ExampleTable, &supportVectors, &model_string, &useNonMeta, cc_KernelFunc, &kernel))
-		return NULL;
-	
+
+	if (!PyArg_ParseTuple(args, "O&sbO&|O&O&:__new__",
+			cc_Domain, &domain,
+			&model_string,
+			&useNonMeta,
+			cc_ExampleTable, &supportVectors,
+			ccn_KernelFunc, &kernel,
+			ccn_ExampleTable, &examples)) {
+
+		 // Old pickle arguments format.
+		PVariable classVar;
+		if (!PyArg_ParseTuple(args, "O&O&O&s|bO&:__new__",
+				cc_Variable, &classVar,
+				ccn_ExampleTable, &examples,
+				cc_ExampleTable, &supportVectors,
+				&model_string,
+				&useNonMeta,
+				cc_KernelFunc, &kernel)) {
+			return NULL;
+		}
+
+		PyErr_Clear();
+		domain = supportVectors->domain;
+	}
+
 	string buffer(model_string);
 	svm_model* model = svm_load_model_alt(buffer);
 	if (!model)
 		raiseError("Error building LibSVM Model");
-//	model->param.learner = NULL;
-	PSVMClassifier svm = mlnew TSVMClassifierSparse(classVar, examples, model, NULL, useNonMeta != 0, kernel);
-//	svm->kernelFunc = kernel;
-	svm->supportVectors = supportVectors;
+
+	PSVMClassifier svm = mlnew TSVMClassifierSparse(domain, model, useNonMeta != 0, supportVectors, kernel, examples);
+
 	return WrapOrange(svm);
-	PyCATCH
+PyCATCH
 }
 
-
-/************ EARTH (MARS) ******/
-#include "earth.hpp"
-
-C_CALL(EarthLearner, Learner, "([examples], [weight=] -/-> Classifier)")
-C_NAMED(EarthClassifier, ClassifierFD, " ")
-
-PyObject *EarthClassifier_formatEarth(PyObject *self, PyObject *args) PYARGS(METH_VARARGS, "() -> None")
-{
-	PyTRY
-	CAST_TO(TEarthClassifier, classifier);
-	classifier->format_earth();
-	RETURN_NONE;
-	PyCATCH
-}
-
-PyObject *EarthClassifier__reduce__(PyObject *self) PYARGS(METH_VARARGS, "")
-{
-	PyTRY
-	CAST_TO(TEarthClassifier, classifier);
-	TCharBuffer buffer(1024);
-	classifier->save_model(buffer);
-	return Py_BuildValue("O(s#)N", getExportedFunction("__pickleLoaderEarthClassifier"),
-									buffer.buf, buffer.length(),
-									packOrangeDictionary(self));
-	PyCATCH
-}
-
-PyObject *__pickleLoaderEarthClassifier(PyObject *self, PyObject *args) PYARGS(METH_VARARGS, "(buffer)")
-{
-	PyTRY
-	char * cbuf = NULL;
-	int buffer_size = 0;
-	if (!PyArg_ParseTuple(args, "s#:__pickleLoaderEarthClassifier", &cbuf, &buffer_size))
-		return NULL;
-	TCharBuffer buffer(cbuf);
-	PEarthClassifier classifier = mlnew TEarthClassifier();
-	classifier->load_model(buffer);
-	return WrapOrange(classifier);
-	PyCATCH
-}
-
-
 	
 /************* BAYES ************/
 
